@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.3.2"
+__version__ = "1.4.0"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -48,7 +48,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=22.1.2"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=22.2"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -186,17 +186,18 @@ def _check_pip_version(raise_on_incompatible=False):  # type: (bool) -> bool
 def _import_toml():  # type: () -> Any
     """Import and return toml or pytoml module (in this order)."""
     exception_names = {
+        "tomllib": "TOMLDecodeError",
         "toml": "TomlDecodeError",
         "pytoml": "TomlError",
         "tomli": "TOMLDecodeError",
     }
 
-    # Only tomli requires TOML files to be opened
+    # Only tomli/tomllib requires TOML files to be opened
     # in binary mode: https://github.com/hukkin/tomli#parse-a-toml-file
     open_kwargs = defaultdict(dict)  # type: Dict[str, Dict[str, str]]
-    open_kwargs["tomli"] = {"mode": "rb"}
+    open_kwargs["tomli"] = open_kwargs["tomllib"] = {"mode": "rb"}
 
-    for module_name in "toml", "pytoml", "tomli":
+    for module_name in "tomllib", "toml", "pytoml", "tomli":
         try:
             module = import_module(module_name)
             exception = getattr(module, exception_names[module_name])
@@ -467,8 +468,10 @@ def _instantiate_package_finder(pip_session):  # type: (PipSession) -> PackageFi
         link_collector = LinkCollector(session=pip_session, search_scope=search_scope)
         additional_kwargs = {}
         # pip 22 deprecates vendored html5lib and uses stdlib html.parser
-        # https://pip.pypa.io/en/latest/news/#id19
-        if Version(pip_version).release >= (22,):
+        # https://github.com/pypa/pip/pull/10291
+        # pip 22.2 will remove that switch
+        # https://github.com/pypa/pip/issues/10825
+        if (22, 2) > Version(pip_version).release >= (22,):
             additional_kwargs["use_deprecated_html5lib"] = False
         return PackageFinder.create(
             link_collector=link_collector,
